/*

  Test for i_azulejos.inc (decorative tile pigment generator, based on functions).

  --
  Jaime Vives Piqueres, Feb. 2004


*/
#version 3.5;

#include "colors.inc"
#include "textures.inc"
#include "woods.inc"
#include "metals.inc"
#include "functions.inc"

// tile pigment macro
#include "i_azulejos.inc"

// global constant for p_tile()
#declare TILE_WARP_SIZE=5;
#declare TILE_WARP_ANGLE=22.5; //22.5, 30, 45, ..

// custom parameters
#declare bc=c_tile_background;
#declare cs=c_tile_separator;
#declare f_test1=function{(sin(abs(x))+cos(abs(y)))}
#declare f_test2=function{(sin(abs(x))*cos(abs(y)))}
#declare f_test3=function{(sin(abs(x))+sin(abs(y)))}
#declare f_test4=function{(sin(x)-cos(y))}

// several color arrays
#declare a_col1=array[1] {c_tile_blue}
#declare a_col1b=array[1] {c_tile_yellow}
#declare a_col1c=array[1] {c_tile_orange}
#declare a_col1d=array[1] {c_tile_green}
#declare a_col1t=array[1] {Clear}
#declare a_col2=array[2] {c_tile_blue,c_tile_yellow}
#declare a_col2b=array[2] {c_tile_green,c_tile_orange}
#declare a_col3=array[3] {c_tile_blue,c_tile_yellow,c_tile_green}
#declare a_col3b=array[3] {c_tile_blue,c_tile_orange,c_tile_green}

// sample tile 
///*
// simple version with one layer :
#declare p1=
pigment{
 p_tile( function{f_test(x+18,y+15,z)*.5}, bc, cs, a_col3b, .6, 0, 0)
 frequency 1
 phase .5
 scale .125
}
#declare tile=
object{basic_tile
 texture{pigment{p1} finish{Phong_Shiny}}
 scale <1,1,.25>*.99
}
//*/
/*
// two layers version:
#declare p1=
pigment{
 p_tile( function{f_test(x+8,y+15,z)*.5}, bc, cs, a_col3b, .6, 0, 0)
 frequency 1
 phase .3
 scale .125
}
#declare p2=
pigment{
 p_tile( function{f_test(x+6,y-1,z)*.5}, bc, cs, a_col1t, .6, 0, 0)
 frequency 1
 phase .5
 scale .125
}
#declare tile=
object{basic_tile
 texture{pigment{p1} finish{Phong_Shiny}}
 texture{pigment{p2} finish{Phong_Shiny}}
 scale <1,1,.25>*.99
}
*/
/*
// two layer with different functions:
#declare p1=
pigment{
 p_tile( function{f_test1(x+3,y+11,z)*.5}, bc, cs, a_col3, .4, .05, 0)
 scale .125
}
#declare p2=
pigment{
 p_tile( function{f_test2(x+8,y+4,z)*.5}, bc, cs, a_col1t, .6, .025, 0)
 scale .125
}
#declare tile=
object{basic_tile
 texture{pigment{p1} finish{Phong_Shiny}}
 texture{pigment{p2} finish{Phong_Shiny}}
 scale <1,1,.25>*.99
}
*/
/*
// a layer for each color plus a "mask" layer:
#declare p1=
pigment{
 p_tile( function{f_test1(x+4,y+3,z)*.5}, bc, cs, a_col1, .3, .03, 1)
 scale .125
}
#declare p2=
pigment{
 p_tile( function{f_test2(x+13,y+9,z)*.5}, Clear, cs, a_col1b, .3, .03, 0)
 scale .125
}
#declare p3=
pigment{
 p_tile( function{f_test3(x+4,y+7,z)*.5}, Clear, cs, a_col1d, .3, .03, 0)
 scale .125
}
#declare p4=
pigment{
 p_tile( function{f_bumps(x+11,y+7,z+23)}, bc, cs, a_col1t, .5, .02, 0)
 scale .125
}
#declare tile=
object{basic_tile
 texture{pigment{p1} finish{Phong_Shiny}}
 texture{pigment{p2} finish{Phong_Shiny}}
 texture{pigment{p3} finish{Phong_Shiny}}
 texture{pigment{p4} finish{Phong_Shiny}}
 scale <1,1,.25>*.99
}
*/

// making a wall of tiles
union{
 object{tile translate <-2,2,0> }
 object{tile translate <-2,1,0> }
 object{tile translate <-2,0,0> }
 object{tile translate <-2,-2,0> }
 object{tile translate <-2,-1,0> }
 object{tile translate <-1,2,0> }
 object{tile translate <-1,1,0> }
 object{tile translate <-1,0,0> }
 object{tile translate <-1,-2,0> }
 object{tile translate <-1,-1,0> }
 object{tile translate < 0,2,0> }
 object{tile translate < 0,1,0> }
 object{tile translate < 0,0,0> }
 object{tile translate < 0,-2,0> }
 object{tile translate < 0,-1,0> }
 object{tile translate < 2,2,0> }
 object{tile translate < 2,1,0> }
 object{tile translate < 2,0,0> }
 object{tile translate < 2,-2,0> }
 object{tile translate < 2,-1,0> }
 object{tile translate < 1,2,0> }
 object{tile translate < 1,1,0> }
 object{tile translate < 1,0,0> }
 object{tile translate < 1,-2,0> }
 object{tile translate < 1,-1,0> }
 translate 3.8*z
}
plane{z,3.69 pigment{White} normal{granite scale .1} finish{Phong_Shiny}}


// test light
light_source{
 <-30,100,-45>
 White*19000
 fade_distance 1
 fade_power 2
}

// something to reflect
sphere{0,400
 pigment{brick}
 finish{Luminous}
}
